@@ -148,50 +148,51 @@ class BasePipelineExplainer(ABC):
         # Get primary attribution scores
         output.token_attributions = None
         output.normalized_token_attributions = None
-        if calculate_attributions and attribution_method == 'grad_x_input':
+        if calculate_attributions:
+            if attribution_method == 'grad_x_input':
 
-            if self.verbose:
-                print("Calculating token attributions... ", end='')
+                if self.verbose:
+                    print("Calculating token attributions... ", end='')
 
-            token_attributions = gradient_x_inputs_attribution(
-                pred_logits=output.image, input_embeds=text_embeddings,
-                explanation_2d_bounding_box=explanation_2d_bounding_box
-            )
-            token_attributions = token_attributions.detach().cpu().numpy()
-
-            # remove special tokens
-            assert len(token_attributions) == len(tokens)
-            output.token_attributions = []
-            output.normalized_token_attributions = []
-            for image_token_attributions, image_tokens in zip(token_attributions, tokens):
-                assert len(image_token_attributions) == len(image_tokens)
-
-                # Add token attributions
-                output.token_attributions.append([])
-                for attr, token in zip(image_token_attributions, image_tokens):
-                    if consider_special_tokens or token not in self.special_tokens_attributes:
-
-                        if clean_token_prefixes_and_suffixes:
-                            token = clean_token_from_prefixes_and_suffixes(token)
-
-                        output.token_attributions[-1].append(
-                            (token, attr)
-                        )
-
-                # Add normalized
-                total = sum([attr for _, attr in output.token_attributions[-1]])
-                output.normalized_token_attributions.append(
-                    [
-                        (token, round(100 * attr / total, 3))
-                        for token, attr in output.token_attributions[-1]
-                    ]
+                token_attributions = gradient_x_inputs_attribution(
+                    pred_logits=output.image, input_embeds=text_embeddings,
+                    explanation_2d_bounding_box=explanation_2d_bounding_box
                 )
+                token_attributions = token_attributions.detach().cpu().numpy()
 
-            if self.verbose:
-                print("Done!")
+                # remove special tokens
+                assert len(token_attributions) == len(tokens)
+                output.token_attributions = []
+                output.normalized_token_attributions = []
+                for image_token_attributions, image_tokens in zip(token_attributions, tokens):
+                    assert len(image_token_attributions) == len(image_tokens)
 
-        else:
-            raise NotImplementedError("Only `attribution_method='grad_x_input'` is implemented for now")
+                    # Add token attributions
+                    output.token_attributions.append([])
+                    for attr, token in zip(image_token_attributions, image_tokens):
+                        if consider_special_tokens or token not in self.special_tokens_attributes:
+
+                            if clean_token_prefixes_and_suffixes:
+                                token = clean_token_from_prefixes_and_suffixes(token)
+
+                            output.token_attributions[-1].append(
+                                (token, attr)
+                            )
+
+                    # Add normalized
+                    total = sum([attr for _, attr in output.token_attributions[-1]])
+                    output.normalized_token_attributions.append(
+                        [
+                            (token, round(100 * attr / total, 3))
+                            for token, attr in output.token_attributions[-1]
+                        ]
+                    )
+
+                if self.verbose:
+                    print("Done!")
+
+            else:
+                raise NotImplementedError("Only `attribution_method='grad_x_input'` is implemented for now")
 
         if batch_size == 1:
             # squash batch dimension
